@@ -14,7 +14,7 @@ use crate::config::{Config, SETTINGS};
 use crate::env::GITHUB_TOKEN;
 use crate::http::HTTP_FETCH;
 use crate::install_context::InstallContext;
-use crate::toolset::ToolRequest;
+use crate::toolset::{ToolRequest, ToolVersion};
 use crate::{env, file};
 
 #[derive(Debug)]
@@ -61,28 +61,32 @@ impl Backend for CargoBackend {
             .cloned()
     }
 
-    fn install_version_impl(&self, ctx: &InstallContext) -> eyre::Result<()> {
+    fn install_version_impl(
+        &self,
+        ctx: &InstallContext,
+        tv: ToolVersion,
+    ) -> eyre::Result<ToolVersion> {
         let config = Config::try_get()?;
-        let install_arg = format!("{}@{}", self.tool_name(), ctx.tv.version);
+        let install_arg = format!("{}@{}", self.tool_name(), tv.version);
 
         let cmd = CmdLineRunner::new("cargo").arg("install");
         let mut cmd = if let Some(url) = self.git_url() {
             let mut cmd = cmd.arg(format!("--git={url}"));
-            if let Some(rev) = ctx.tv.version.strip_prefix("rev:") {
+            if let Some(rev) = tv.version.strip_prefix("rev:") {
                 cmd = cmd.arg(format!("--rev={rev}"));
-            } else if let Some(branch) = ctx.tv.version.strip_prefix("branch:") {
+            } else if let Some(branch) = tv.version.strip_prefix("branch:") {
                 cmd = cmd.arg(format!("--branch={branch}"));
-            } else if let Some(tag) = ctx.tv.version.strip_prefix("tag:") {
+            } else if let Some(tag) = tv.version.strip_prefix("tag:") {
                 cmd = cmd.arg(format!("--tag={tag}"));
-            } else if ctx.tv.version != "HEAD" {
-                Err(eyre!("Invalid cargo git version: {}", ctx.tv.version).note(
+            } else if tv.version != "HEAD" {
+                Err(eyre!("Invalid cargo git version: {}", tv.version).note(
                     r#"You can specify "rev:", "branch:", or "tag:", e.g.:
       * mise use cargo:eza-community/eza@tag:v0.18.0
       * mise use cargo:eza-community/eza@branch:main"#,
                 ))?;
             }
             cmd
-        } else if self.is_binstall_enabled(ctx) {
+        } else if self.is_binstall_enabled(&tv) {
             let mut cmd = CmdLineRunner::new("cargo-binstall").arg("-y");
             if let Some(token) = &*GITHUB_TOKEN {
                 cmd = cmd.env("GITHUB_TOKEN", token)
@@ -94,7 +98,7 @@ impl Backend for CargoBackend {
             cmd.arg(install_arg)
         };
 
-        let opts = ctx.tv.request.options();
+        let opts = tv.request.options();
         if let Some(features) = opts.get("features") {
             cmd = cmd.arg(format!("--features={}", features));
         }
@@ -106,14 +110,14 @@ impl Backend for CargoBackend {
 
         cmd.arg("--locked")
             .arg("--root")
-            .arg(ctx.tv.install_path())
+            .arg(tv.install_path())
             .with_pr(ctx.pr.as_ref())
             .envs(ctx.ts.env_with_path(&config)?)
             .prepend_path(ctx.ts.list_paths())?
             .prepend_path(self.dependency_toolset()?.list_paths())?
             .execute()?;
 
-        Ok(())
+        Ok(tv)
     }
 }
 
@@ -129,7 +133,7 @@ impl CargoBackend {
         }
     }
 
-    fn is_binstall_enabled(&self, ctx: &InstallContext) -> bool {
+    fn is_binstall_enabled(&self, tv: &ToolVersion) -> bool {
         if !SETTINGS.cargo.binstall {
             return false;
         }
@@ -140,7 +144,7 @@ impl CargoBackend {
         {
             return false;
         }
-        let opts = ctx.tv.request.options();
+        let opts = tv.request.options();
         if opts.contains_key("features") || opts.contains_key("default-features") {
             info!("not using cargo-binstall because features are specified");
             return false;
