@@ -75,19 +75,6 @@ mod tests {
 
     use crate::test::reset;
 
-    #[test]
-    fn test_fake_asdf_list() {
-        reset();
-        assert_cli!("uninstall", "--all", "tiny");
-        assert_cli!("install", "tiny@1", "tiny@2");
-        assert_cli!("asdf", "install", "tiny");
-        assert_cli_snapshot!("asdf", "list", "tiny", @r"
-        1.0.1
-        2.1.0
-        3.1.0
-        ");
-    }
-
     #[test]
     fn test_fake_asdf_other() {
         reset();
