@@ -59,7 +59,7 @@ impl Set {
             return Ok(());
         }
 
-        let filename = if let Some(env) = &*env::MISE_ENV {
+        let filename = if let Some(env) = &*env::MISE_PROFILE {
             config_file_from_dir(&env::current_dir()?.join(format!(".mise.{}.toml", env)))
         } else if self.global {
             env::MISE_GLOBAL_CONFIG_FILE.clone()
