@@ -21,17 +21,23 @@ use path_absolutize::Absolutize;
 pub struct ToolVersion {
     pub request: ToolRequest,
     pub version: String,
+    pub checksum: Option<String>,
 }
 
 impl ToolVersion {
     pub fn new(request: ToolRequest, version: String) -> Self {
-        ToolVersion { request, version }
+        ToolVersion {
+            request,
+            version,
+            checksum: None,
+        }
     }
 
     pub fn resolve(request: ToolRequest, opts: &ResolveOptions) -> Result<Self> {
         if opts.use_locked_version {
-            if let Some(v) = request.lockfile_resolve()? {
-                let tv = Self::new(request.clone(), v);
+            if let Some(lt) = request.lockfile_resolve()? {
+                let mut tv = Self::new(request.clone(), lt.version);
+                tv.checksum = lt.checksum;
                 return Ok(tv);
             }
         }
